BulkParts

Struct BulkParts 

struct BulkParts {
    unordered_part: UnorderedPart,
    parts: Vec<BulkPartWrapper>,
}
All parts in a bulk memtable.

Fields

unordered_part: UnorderedPart

Unordered small parts.

parts: Vec<BulkPartWrapper>

All parts (raw and encoded).

Implementations

Source

impl BulkParts

fn num_parts(&self) -> usize

Total number of parts (including unordered).

fn is_empty(&self) -> bool

Returns true if there is no part.

fn should_merge_parts( &self, merge_threshold: usize, encode_bytes_threshold: usize, ) -> bool

Returns true if enough parts of the same type are available to merge.

fn is_merge_candidate( wrapper: &BulkPartWrapper, encode_bytes_threshold: usize, ) -> bool

Returns whether a part is small enough to benefit from merging.

fn is_merge_candidate_by_size( is_encoded: bool, estimated_size: usize, encode_bytes_threshold: usize, ) -> bool

fn should_compact_unordered_part(&self, encode_bytes_threshold: usize) -> bool

Returns true if the unordered_part should be compacted into a BulkPart.

fn collect_parts_to_merge( &mut self, merge_threshold: usize, max_merge_groups: usize, encode_bytes_threshold: usize, ) -> CollectedParts

Collects unmerged parts and marks them as being merged. Only collects parts of types that meet the threshold. Parts are grouped by row count for parallel processing.

fn collect_and_group_parts( &mut self, indices: Vec<(usize, usize)>, merge_threshold: usize, max_merge_groups: usize, ) -> Vec<Vec<PartToMerge>>

Sorts indices by row count, groups into chunks, marks as merging, and returns groups.

fn install_merged_parts<I>( &mut self, merged_parts: I, merged_file_ids: &HashSet<FileId>, ) -> usize
where I: IntoIterator<Item = MergedPart>,

Installs merged parts and removes the original parts by file ids. Returns the total number of rows in the merged parts.

fn reset_merging_flags(&mut self, file_ids: &HashSet<FileId>)

Resets merging flag for parts with the given file ids. Used when merging fails or is cancelled.